@@ -81,14 +81,6 @@ def Seismic_SEL(data,rng,Fs,sens=1e5/19.7,plotFlag=True,logFlag=True):
             plt.xlabel('Range (m)')
             plt.ylabel('SEL (dB)')
             plt.ylim(yLims)
-            if MammalFlag == True:
-                plt.plot(rng,168*np.ones(len(rng)),'r--',linewidth=3)
-                plt.plot(rng,183*np.ones(len(rng)),'r:',linewidth=3)
-                plt.title('SEL (Marine Mammal Weighted)')
-                plt.legend(['SEL-Weighted','TTS','PTS'])
-            else:
-                plt.title('Sound Exposure Level')
-            plt.show()
         else:
             fig = plt.figure()
             ax = plt.gca()
@@ -97,13 +89,6 @@ def Seismic_SEL(data,rng,Fs,sens=1e5/19.7,plotFlag=True,logFlag=True):
             plt.xlabel('Range (m)')
             plt.ylabel('SEL (dB)')
             plt.ylim(yLims)
-            if MammalFlag == True:
-                plt.plot(rng,168*np.ones(len(rng)))
-                plt.plot(rng,183*np.ones(len(rng)))
-                plt.title('SEL (Marine Mammal Weighted)')
-                plt.legend(['SEL-Weighted','TTS','PTS'])
-            else:
-                plt.title('Sound Exposure Level')
             plt.show()
             
     return SEL
